@@ -7,7 +7,6 @@ import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalExcept
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.geospatial.GeospatialCreateCoordinatesSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
 import org.gcube.portlets.user.td.columnwidget.client.geospatial.GeospatialCoordinatesTypePropertiesCombo;
@@ -24,6 +23,7 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.RequestProperties;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.RequestPropertiesParameterType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.geospatial.GeospatialCoordinatesType;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnDataType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnTypeCode;
 
